@@ -112,6 +112,7 @@ class SpacerakeSDK:
 
     async def __request_make(self, method, path, data=None, params=None):
         auth_header = f'Bearer {self.api_key}/{self.api_secret}'
+        timeout = httpx.Timeout(60.0, connect=10.0)
         async with httpx.AsyncClient() as client:
             resp = await client.request(
                 method,
@@ -120,7 +121,8 @@ class SpacerakeSDK:
                     'Authorization': auth_header
                 },
                 data=data,
-                params=params
+                params=params,
+                timeout=timeout
             )
 
             return resp
@@ -131,7 +133,7 @@ class SpacerakeSDK:
             'GET',
             path,
             data=data,
-            params=params
+            params=params,
         )
 
 
@@ -347,3 +349,12 @@ class SpacerakeSDK:
             raise SpacerakeAPIException(APIResponse[Any].parse_obj(resp.json()).error)
 
         return resp.headers['location']
+
+    # --- OSM ---
+    async def search_geocode(self, query: str) -> List[Any]:
+        return await self.__abstract_get(
+            f'/api/v0/search/geocode',
+            List[Any],
+            params={'query': query}
+        )
+
